Reference
=========

The specifics of the library.

Routines
--------

.. automodule:: survey.routines
    :members:

Printers
--------

.. automodule:: survey.printers
    :members:

Graphics
--------

.. automodule:: survey.graphics
    :members:

Widgets
-------

.. automodule:: survey.widgets
    :members:

Theme
-----
.. automodule:: survey.theme
    :members:

Funnels
-------

.. automodule:: survey.funnels
    :members:

Colors
------

.. automodule:: survey.colors
    :members:

Mutates
-------

.. automodule:: survey.mutates
    :members:

Visuals
-------

Visuals guide the rendering of data in predictible ways.

.. automodule:: survey.visuals
    :members:

Handle
------

.. automodule:: survey.handle
    :members:

Core
----

The internal tools of the library.

.. automodule:: survey.core
    :members:

ansi
^^^^

.. automodule:: survey.core.ansi
    :members:
    